.. You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Content

   changelog
   Package Overview <source/adaptavist>


Readme
======

.. mdinclude:: ../README.md
   :start-line: 2
